package CLI::ComputerFiles::Util;

use 5.006;
use strict;
use warnings;

=head1 NAME

CLI::ComputerFiles::Util - dirhier and madeafter. To supplement Unix/Linux commands for handling Files.

  dirhier  -- Given directory names, it shows how many files/bytes/directories on directries at each depth in directory hierarchy. 
  madeafter -- It simultaneously shows the 3 time information of files : how many seconds/mins/hours/days have passed until now. 

  The detail can be available by   "dirhier --help" , "madeafter --help". 

=head1 VERSION

Version 0.101

=cut

our $VERSION = '0.101';


=head1 SYNOPSIS


=head1 LICENSE AND COPYRIGHT

Copyright 2018 "Toshiyuki Shimono".

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see L<http://www.gnu.org/licenses/>.


=cut

1; # End of CLI::ComputerFiles::Util
